@@ -18,7 +18,8 @@ LearnerDensHistogram = R6::R6Class("LearnerDensHistogram",
         )),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         predict_types = c("pdf", "cdf"),
-        packages = c("distr6")
+        packages = c("distr6"),
+        man = "mlr3proba::mlr_learners_dens.hist"
       )
     }
   ),
@@ -36,7 +37,8 @@ LearnerDensHistogram = R6::R6Class("LearnerDensHistogram",
 
     .predict = function(task) {
       newdata = as.numeric(unlist(task$data(cols = task$target_names)))
-      PredictionDens$new(task = task, pdf = self$model$distr$pdf(newdata), cdf = self$model$distr$cdf(newdata))
+      PredictionDens$new(task = task, pdf = self$model$distr$pdf(newdata),
+                         cdf = self$model$distr$cdf(newdata))
     }
   )
 )
