@@ -22,19 +22,22 @@ MeasureSurvGonenC = R6Class("MeasureSurvGonenC",
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
+      warning("This is now deprecated, use MeasureSurvCindex instead with `weight_meth = 'GH'`.")
+
       super$initialize(
         id = "surv.gonenC",
         range = 0:1,
         minimize = FALSE,
         packages = "survAUC",
-        predict_type = "lp"
+        predict_type = "lp",
+        man = "mlr3proba::mlr_measures_surv.gonenC"
       )
     }
   ),
 
   private = list(
     .score = function(prediction, ...) {
-      survAUC::GHCI(prediction$lp)
+      c_gonen(prediction$lp, 0.5)
     }
   )
 )
