@@ -25,8 +25,10 @@ MeasureSurvHungAUC = R6Class("MeasureSurvHungAUC",
       super$initialize(
         integrated = integrated,
         times = times,
-        id = "surv.hungAUC",
-        properties = c("requires_task", "requires_train_set"))
+        id = "surv.hung_auc",
+        properties = c("requires_task", "requires_train_set"),
+        man = "mlr3proba::mlr_measures_surv.hung_auc"
+      )
     }
   ),
 
